# Towards Effective Smoking Cessation: Understanding the Needs of Daily Smokers from eHealth Chatbot Interactions

**Author:** Vlad Iftimescu
**Date:** January 2024

This file serves for providing readers with information to understand and reproduce the analysis described in the paper: "Towards Effective Smoking Cessation: Understanding the Needs of Daily Smokers from eHealth Chatbot Interactions".

This work is part of the multidisciplinary research project Perfect Fit, which is supported by several funders organized by the Netherlands Organization for Scientific Research (NWO), program Commit2Data - Big Data & Health (project number 628.011.211). Besides NWO, the funders include the Netherlands Organisation for Health Research and Development (ZonMw), Hartstichting, the Ministry of Health, Welfare, and Sport (VWS), Health Holland, and the Netherlands eScience Center.

### Disclaimers:
The data that was used for the Python scripts and thus the analysis is not currently available for public use. To maintain privacy, the data files attached to this folder have been anonymized, and as such most of the Python scripts cannot be run at the moment.

### Explanation of the Folders:
- Data Files - contains all dataset files that were used for the Python scripts. The data in these files was anonymized
- Images - contains the figures/tables used in the paper in .PNG format. Note: Figure 1 data was calculated using ATLAS.ti, and Table 1 data was calculated by hand
- Scripts - contains all Python scripts which were used for the analysis
### Explanation of the Data Files:
Since I am not allowed to include the sensitive information from the original data files here, I will explain their structure so that the reader can better understand how the Python scripts tie in with the data:
- **Code_Co_Occurrence.xlsx** - contains the co-occurrence table for the codes over the full thematic analysis
- **User_Needs_COOC** - contains the co-occurrence table for the codes over the 131-quotation dataset
- **cohens_kappa_values.xlsx**, which has 2 columns:
	- Code - string representing the thematic analysis code
	- Cohen's Kappa value - value computed by the calculate_cohens_kappa.py script for the code
- **Research_Project_Final_Quotations_Anon.xlsx** which has 2 columns:
	- Quotation Content - string representing the thematic analysis quotation
	- Codes - list of codes attributed by us to the quotation
- **Peer_Review_Quotations_Anon.xlsx** - same as Research_Project_Final_Quotations_Anon.xlsx, but containing the codes attributed by the second coder
- **User_Needs_Quotations_Anon.xlsx** - same as Research_Project_Final_Quotations_Anon.xlsx, but only with the 131 quotations
- **pids_codes_characteristics_Anon.xlsx** contains 3 sheets:
	- Sheet 1 has 8 columns:
		- rand_id - PID of the user
		- session_num - session number of the activity. Possible values: 1, 2, 3, 4, 5
		- activity_experience_slot - string  representing user quotation
		- Codes - list of codes attributed by us
		- Peer Codes - list of codes attributed by second coder
		- Gender - string denoting user's gender. Values can be "Man (including Trans Male/Trans Man)", "Woman (including Trans Female/Trans Woman)", "Non-binary (would like to give more detail)", "Rather not say"
		- Highest education level completed - string denoting user's highest completed education level. Values can be "No formal qualifications", "Secondary education (e.g. GED/GCSE)", "High school diploma/A-levels", "Technical/community college", "Undergraduate degree (BA/BSc/other)", "Graduate degree (MA/MSc/MPhil/other)", "Doctorate degree (PhD/other)", "Don't know / not applicable"
		- Age - user's age in years
	- Sheet 2 contains some general user characteristic statistics for each theme (used for Table 1 in the paper):
		- Rows - one of the themes
		- Number quotations - number of quotations which exhibited theme
		- Number female - number of quotations from theme that were given by women
		- Number non-binary - number of quotations from theme that were given by non-binary people
		- Number male- number of quotations from theme that were given by men
		- Mean age - mean of ages over the quotations that exhibited the theme
		- SD age - standard deviation of ages over the quotations that exhibited the theme
		- Min. age - minimum of ages over the quotations that exhibited the theme
		- Max. age - maximum of ages over the quotations that exhibited the theme
		- % quotations, % female, % NB, % male - percentages of quotations which exhibited the theme and the characteristic out of the 131 quotations dataset
		- General male ... General max - same as Number male ... Number max but over the full dataset
		- Needs female ... Needs max - same statistics, but performed over all unique people from the 131-quotation dataset
	- Sheet 3 contains the P-values of the correlation tests (used for Table 2 in the paper):
		- Gender chi-square P-value - P-value resulted from performing the chi-square test using the chi_squared_test.py script
		- Age Pearson P-value - P-value resulted from performing Pearson's correlation using the correlation_age_theme.py script
		- Education Spearman P-value - P-value resulted from performing Spearman's rank correlation using the correlation_education_theme.py script
- **ProcessedSessionsData_Anon.xlsx** - the initial dataset containing the user responses, their effort values and competencies:
	- rand_id - PID of the user
	- session_num - session number of the activity. Possible values: 1, 2, 3, 4, 5
	- response value - state_1, state_2, state_3, state_4, state_5, state_6, state_7, state_8, state_9, state_busy, state_energy, activity_new_index, cluster_new_index, effort, dropout_response, mood, activity_experience_slot, activity_experience_mod_slot. The first nine state features denote the usefulness beliefs, rated on scales from -10 to 10. state_busy is based on the question "How busy are you compared to your normal situation?", rated on a scale from -5 ("much less") to 5 ("much more"). state_energy is based on the question "How much energy do you have?" , rated on a scale from 0 ("none") to 10 ("extremely much"). activity_new_index is the index of the activity assigned in the session (0 - 43 are the preparatory activities, 44 - 52 are the persuasive activities). cluster_new_index considers that the preparatory activities are clustered into 5 clusters for the effort prediction (1-5 are the 5 preparatory activity clusters, 6 - 14 are the persuasive activities). effort is based on the question "Please rate the overall effort you put into doing this activity.", rated on a scale from 0 ("nothing") to 10 ("extremely strong"), adapted based on the scale by Hutchinson and Tenenbaum (2006). dropout_response is based on the question "Currently you are taking part in a paid experiment. Imagine this was an unpaid smoking cessation program. How likely would you then have quit the program or returned to this session?", rated on a scale from -5 ("definitely would have quit the program") to 5 ("definitely would have returned to this session"). mood is the answer to the question "How are you feeling today?" with possible answer options being adjectives from the paper "A circumplex model of affect" by Russell (these adjectives can be mapped to dominance, valence, and arousal scores based on the ratings from the paper "Obtaining reliable human ratings of valence, arousal, and dominance for 20,000 English words" by Mohammad). activity_experience_slot is the answer to the question "How did you approach, do, or experience your assigned activity?" (if participants reported spending low effort on their previous activity, we add this to the question: "If you have no feedback on the activity, just type 'None' in the text field."). activity_experience_mod_slot is the answer people gave when being given the opportunity to change their activity experience response. "[…]" indicates potentially identifying or health data that has been removed during the anonymization process.
- **FrankensteinDataPIDs_Anon.xlsx** - same as ProcessedSessionsData_Anon.xlsx, but containing PIDs on each row of the file

### Explanation of the Scripts:
- **add_pids.py** - Merges 2 Excel data files. Used to add the PIDs and session number information to certain files.
- **calculate_cohens_kappa.py** - Calculates the Cohen's Kappa values for all codes that were used for the thematic analysis. The script assumes that the quotations in the 2 files have the same order. Creates the file cohens_kappa_values.xlsx
- **change_processed_sessions_data.py** - Adds the PIDs to every row of the initial (full) dataset of user responses. Creates the file FrankensteinDataPIDs_Anon.xlsx
- **chi_squared_test.py** - Performs the chi-squared test for the gender-theme correlations. Computes the output that can be seen in the paper in Table 2
- **correlation_age_theme.py** - Computes the Pearson correlation between users' ages and the themes. Output can be seen in Figure 2 and Table 2.
- **correlation_education_theme.py** - Computes the Spearman correlation between users' highest completed educational levels and the themes. Output can be seen in Figure 3 and Table 2.
- **quantitative_pre_data.py** - Computes some basic statistical data about the user characteristics in the initial (full) dataset file.