'''
Performs the chi-squared test for the gender-theme correlations.

Author: Vlad Iftimescu
Date: January 2024

Input: Data from Table 1 in the paper
Output used: P-values which were added to Table 2 in the paper
'''

from scipy.stats import chi2_contingency

# Create the contingency table
# Format of the table: [[# female quotations with theme, # male quotations with theme],
#                       [# female quotations in the filtered dataset, # male quotations in the filtered dataset]]
observed = [[14, 14],
            [65, 60]]

# Perform the chi-square test
chi2_stat, p_value, dof, expected = chi2_contingency(observed)

# Check the p-value
if p_value < 0.05:
    print("There is a significant difference in the proportion of females.")
else:
    print("There is no significant difference in the proportion of females.")

# Output the test statistics and expected frequencies
print(f"Chi-square statistic: {chi2_stat}")
print(f"P-value: {p_value}")
print(f"Degrees of freedom: {dof}")
print("Expected frequencies:")
print(expected)