'''
Computes some basic statistical data about the user characteristics in the initial (full) dataset file.

Author: Aaron Maguire
Date: January 2024

Input: prolific_profile_anonym_Anon.xlsx - data file containing the PIDs and user characteristics of each participant
        ProcessedSessionsData_Anon.xlsx - initial (full) dataset file
Output: frequency of each education level, age min, max, mean and SD, as well as frequencies of each gender
'''

import openpyxl
import numpy as np

FILE_1_PATH = "prolific_profile_anonym_Anon.xlsx"
FILE_2_PATH = "ProcessedSessionsData_Anon.xlsx"

# Array of education levels options
education_Levels = ["No formal qualifications", "Secondary education (e.g. GED/GCSE)", "High school diploma/A-levels", "Technical/community college", "Undergraduate degree (BA/BSc/other)", "Graduate degree (MA/MSc/MPhil/other)", "Doctorate degree (PhD/other)", "Don't know / not applicable"]
education_Level_Counter = [0, 0, 0, 0, 0, 0, 0, 0]
# Array of gender options
gender_identity = ["Man (including Trans Male/Trans Man)", "Woman (including Trans Female/Trans Woman)", "Non-binary (would like to give more detail)", "Rather not say"]
gender_quantity = [0, 0, 0, 0]
age_Total = 0
age_valid = 0

#loop through file 2, grab all PIDs
file_2 = openpyxl.load_workbook(FILE_2_PATH).active
PID = [] # Used to keep track of the PIDs
ages = []
cnt_row = file_2.max_row
for i in range(2, cnt_row):
    grabbedPID = str(file_2.cell(row = i, column = 1).value)
    if grabbedPID not in PID and grabbedPID is not "None": # If the current PID was not encountered before, add it to the list
        PID.append(grabbedPID)


# Loop through file 1, update the statistical data
file_1 = openpyxl.load_workbook(FILE_1_PATH).active
cnt_row = file_1.max_row
for i in range(2, cnt_row):
    # Extract the user characteristics data for the current PID
    grabbedEdu = str(file_1.cell(row = i, column = 3).value)
    grabbedPID = str(file_1.cell(row = i, column = 5).value)
    grabbedGender = str(file_1.cell(row = i, column = 2).value)
    grabbedAge = int(file_1.cell(row = i, column = 4).value)

    # Update frequencies
    if grabbedPID in PID:
        education_Level_Counter[education_Levels.index(grabbedEdu)] += 1
        ages.append(grabbedAge)
        gender_quantity[gender_identity.index(grabbedGender)] += 1


# Calculate statistical data and print results
print(education_Level_Counter)
print("Age mean:" + str(np.mean(ages)))
print("Age SD:" + str(np.std(ages)))
print("Age min:" + str(np.min(ages)))
print("Age max:" + str(np.max(ages)))
print(gender_quantity)